pagebotcocoa.apps package
=========================

Subpackages
-----------

.. toctree::

   pagebotcocoa.apps.canvas

Submodules
----------

pagebotcocoa.apps.baseapp module
--------------------------------

.. automodule:: pagebotcocoa.apps.baseapp
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.apps.canvasapp module
----------------------------------

.. automodule:: pagebotcocoa.apps.canvasapp
   :members:
   :undoc-members:
   :show-inheritance:

pagebotcocoa.apps.pagebotdemoapp module
---------------------------------------

.. automodule:: pagebotcocoa.apps.pagebotdemoapp
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pagebotcocoa.apps
   :members:
   :undoc-members:
   :show-inheritance:
